@@ -5,8 +5,8 @@
 * Botan is released under the Simplified BSD License (see license.txt)
 */
 
-#ifndef BOTAN_X509_CERTS_H__
-#define BOTAN_X509_CERTS_H__
+#ifndef BOTAN_X509_CERTS_H_
+#define BOTAN_X509_CERTS_H_
 
 #include <botan/x509_obj.h>
 #include <botan/x509_dn.h>
@@ -16,7 +16,6 @@
 #include <botan/datastor.h>
 #include <botan/key_constraint.h>
 #include <botan/name_constraint.h>
-#include <map>
 #include <memory>
 
 namespace Botan {
@@ -33,7 +32,7 @@ enum class Usage_Type
 /**
 * This class represents X.509 Certificate
 */
-class BOTAN_DLL X509_Certificate : public X509_Object
+class BOTAN_PUBLIC_API(2,0) X509_Certificate : public X509_Object
    {
    public:
       /**
@@ -330,7 +329,7 @@ class BOTAN_DLL X509_Certificate : public X509_Object
 * @return true if the arguments represent different certificates,
 * false if they are binary identical
 */
-BOTAN_DLL bool operator!=(const X509_Certificate& cert1, const X509_Certificate& cert2);
+BOTAN_PUBLIC_API(2,0) bool operator!=(const X509_Certificate& cert1, const X509_Certificate& cert2);
 
 /*
 * Data Store Extraction Operations
@@ -341,14 +340,14 @@ BOTAN_DLL bool operator!=(const X509_Certificate& cert1, const X509_Certificate&
 * @param info data store containing DN information
 * @return DN containing attributes from data store
 */
-BOTAN_DLL X509_DN create_dn(const Data_Store& info);
+BOTAN_PUBLIC_API(2,0) X509_DN create_dn(const Data_Store& info);
 
 /*
 * Create and populate an AlternativeName
 * @param info data store containing AlternativeName information
 * @return AlternativeName containing attributes from data store
 */
-BOTAN_DLL AlternativeName create_alt_name(const Data_Store& info);
+BOTAN_PUBLIC_API(2,0) AlternativeName create_alt_name(const Data_Store& info);
 
 }
 
